"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const program = require("commander");
const shared_1 = require("../shared");
const DEFAULT_DIST_DIR_NAME = "dist";
const DEFAULT_CONFIG_FILE_NAME = "tempack.json";
class Cmd {
    constructor(srcPath = process.cwd()) {
        this.options = {
            srcPath,
            distPath: path_1.resolve(srcPath, DEFAULT_DIST_DIR_NAME),
            configPath: path_1.resolve(srcPath, DEFAULT_CONFIG_FILE_NAME),
            packagePath: path_1.resolve(srcPath, shared_1.PACKAGE_FILE_NAME),
        };
        try {
            const { version } = require(path_1.resolve(__dirname, "..", "..", shared_1.PACKAGE_FILE_NAME));
            this.version = version;
        }
        catch (err) {
            this.version = "0.0.0";
        }
    }
    parseArgv(argv = process.argv) {
        const result = Object.assign({}, this.options);
        const { srcPath } = this.options;
        const { args, configPath, packagePath, silent, disableColors, } = this.program.parse(argv);
        if (args[0]) {
            result.distPath = path_1.resolve(srcPath, args[0]);
        }
        if (configPath) {
            result.configPath = path_1.resolve(srcPath, configPath);
        }
        if (packagePath) {
            result.packagePath = path_1.resolve(srcPath, packagePath);
        }
        result.silent = !!silent;
        result.disableColors = !!disableColors;
        return result;
    }
    get program() {
        return program
            .version(this.version, "-v, --version")
            .usage("[options] <dist>")
            .arguments("<dist>")
            .option("-c, --config-path [path]", "config file path", DEFAULT_CONFIG_FILE_NAME)
            .option("-p, --package-path [path]", "package file path", shared_1.PACKAGE_FILE_NAME)
            .option("-s, --silent", "turn on silent mode", false)
            .option("--disable-colors", "turn off colors", false);
    }
}
exports.Cmd = Cmd;
//# sourceMappingURL=Cmd.js.map