"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const fs_1 = require("fs");
const util_1 = require("util");
const ENCODING = "utf8";
const statAsync = util_1.promisify(fs_1.stat);
const readFileAsync = util_1.promisify(fs_1.readFile);
const writeFileAsync = util_1.promisify(fs_1.writeFile);
class FS {
    constructor() {
        this.copyPath = fs_extra_1.copy;
    }
    dirExists(filePath) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            try {
                const stat = yield statAsync(filePath);
                result = stat.isDirectory();
            }
            catch (err) {
                result = false;
            }
            return result;
        });
    }
    fileExists(filePath) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            try {
                const stat = yield statAsync(filePath);
                result = stat.isFile();
            }
            catch (err) {
                result = false;
            }
            return result;
        });
    }
    readFile(filePath) {
        return readFileAsync(filePath, ENCODING);
    }
    writeFile(filePath, content) {
        return writeFileAsync(filePath, content, ENCODING);
    }
    readJSON(filePath) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            try {
                const data = yield this.readFile(filePath);
                result = JSON.parse(data);
            }
            catch (err) {
                result = null;
            }
            return result;
        });
    }
    writeJSON(filePath, item) {
        const content = JSON.stringify(item, null, 2);
        return this.writeFile(filePath, content);
    }
}
exports.FS = FS;
//# sourceMappingURL=FS.js.map