"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const safe_1 = require("colors/safe");
const LOGGER_PREFIX = "tempack";
const LOGGER_PADDING_BASE = 8;
var Types;
(function (Types) {
    Types["Success"] = "success";
    Types["Info"] = "info";
    Types["Error"] = "error";
})(Types || (Types = {}));
class Logger {
    constructor(options, printer = console.log) {
        this.options = options;
        this.printer = printer;
        this.success = this.success.bind(this);
        this.info = this.info.bind(this);
        this.error = this.error.bind(this);
    }
    success(message) {
        this.print(Types.Success, message);
    }
    info(message) {
        this.print(Types.Info, message);
    }
    error(err) {
        let message = "unknown";
        if (err instanceof Error) {
            message = err.message;
        }
        this.print(Types.Error, message);
    }
    print(type, message) {
        const { silent, disableColors } = this.options;
        if (!silent) {
            let color = (value) => value;
            if (!disableColors) {
                switch (type) {
                    case Types.Success:
                        color = safe_1.green;
                        break;
                    case Types.Info:
                        color = safe_1.cyan;
                        break;
                    case Types.Error:
                        color = safe_1.red;
                        break;
                }
            }
            const padding = " ".repeat(LOGGER_PADDING_BASE - type.length);
            this.printer(`[ ${color(LOGGER_PREFIX)} ] [ ${color(type)} ]${padding}${message}`);
        }
    }
}
exports.Logger = Logger;
//# sourceMappingURL=Logger.js.map